@@ -4,7 +4,7 @@ import sys
 from functools import partial
 from pathlib import Path
 from shutil import copy, copytree
-from subprocess import CalledProcessError, check_call, check_output
+from subprocess import PIPE, CalledProcessError, check_call, check_output
 from tempfile import TemporaryDirectory
 from typing import TYPE_CHECKING
 
@@ -45,9 +45,9 @@ class Registry:
             gen_rmtree(self.paths.dir)
             self.paths.dir.mkdir(parents=True)
             try:
-                check_call(["git", "clone", conf.registry, self.posix])
+                git_run(clone=(conf.registry, self.posix))
             except CalledProcessError:  # pragma: no cover
-                check_call(["git", "clone", _de_auth(conf.registry, True), self.posix])
+                git_run(clone=(_de_auth(conf.registry, True), self.posix))
 
             self.paths.ensure()
         self.requires = [
@@ -116,7 +116,7 @@ class Registry:
         comm = [sys.executable, "-m", "pip", "install", f"--find-links={addr}"]
         extras = ["--no-cache", "--no-build-isolation"]
         backup_ind = ["--extra-index-url", "https://pypi.org/simple"]
-        check_call(comm + backup_ind + extras + packages)
+        check_call(comm + backup_ind + extras + packages, stdout=PIPE)
 
     def _dump_meta(self):
         pack_paths = PackPaths(self.name)
@@ -133,12 +133,13 @@ class Registry:
     def _get_info(self):
         remote_comm = ["git", "config", "--get", "remote.origin.url"]
         uri = check_output(remote_comm).decode("utf-8").strip()
-        return {"uri": _de_auth(uri), "tags": self._get_tags()}
+        # WET Project metadata params
+        return {"uri": _de_auth(uri), "tags": self._get_tags(), "cron": self.conf.cron}
 
     def _is_released(self):
         try:
             comm = ["git", "cat-file", "-e", f"origin/main:{self.paths.dist_gitpath}"]
-            check_call(comm, cwd=self.posix)
+            check_call(comm, cwd=self.posix, stdout=PIPE, stderr=PIPE)
             msg = f"can't package {self.name}-{self.conf.version} - already released"
             logger.warning(msg)
             return True
