@@ -1,18 +1,15 @@
 import re
 from contextlib import contextmanager
 from pathlib import Path
-from subprocess import check_call
-from typing import TYPE_CHECKING
 
 from structlog import get_logger
 
-from .config_loading import Config, ImportedProject, ProjectEnv
+from .config_loading import Config
 from .get_runtime import get_runtime
 from .naming import (
     CONSTR,
     DEFAULT_REGISTRY,
     MAIN_MODULE_NAME,
-    META_MODULE_NAME,
     SANDBOX_DIR,
     SANDBOX_NAME,
     TEMPLATE_REPO,
@@ -20,11 +17,7 @@ from .naming import (
 from .registry import Registry
 from .sql.draw import dump_graph
 from .sql.loader import SqlLoader
-from .utils import cd_into
-
-if TYPE_CHECKING:
-    from .project_runtime import ProjectRuntime  # pragma: no cover
-
+from .utils import cd_into, git_run
 
 logger = get_logger(ctx="validation")
 
@@ -76,26 +69,6 @@ def sql_validation(constr, env, draw=False, batch_size=2000):
         loader.purge()
 
 
-def validate_importable(runtime: "ProjectRuntime"):
-    name = runtime.config.name
-    envs = runtime.config.validation_envs
-    with sandbox_project(runtime.config.registry) as core_path:
-        test_conf = Config(
-            name=SANDBOX_NAME,
-            version="v0.0",
-            imported_projects=[ImportedProject(name)],
-            envs=[ProjectEnv(f"test_{env}", import_envs={name: env}) for env in envs],
-            registry=runtime.config.registry,
-        )
-        test_reg = Registry(test_conf)
-        test_reg.full_build()
-        test_conf.dump()
-        core_path.write_text(f"from {META_MODULE_NAME} import {name}")
-        type(runtime)().load_all_data()
-        # TODO: assert this data matches local
-        test_reg.purge()
-
-
 def is_underscored_name(s):
     _check_match("_", s)
 
@@ -111,7 +84,7 @@ def is_step_name(s):
 @contextmanager
 def sandbox_project(registry=DEFAULT_REGISTRY):
     if not SANDBOX_DIR.exists():
-        check_call(["git", "clone", TEMPLATE_REPO, SANDBOX_DIR.as_posix()])
+        git_run(clone=(TEMPLATE_REPO, SANDBOX_DIR.as_posix()))
         with cd_into(SANDBOX_DIR):
             conf = Config(SANDBOX_NAME, "v0.0", registry=registry)
             conf.dump()
